# testing with:
# make --trace --debug=b -f test.mak
# expectation is each of repo-a repo-b repo-c will be called should see something like:
# REPO_CLONE 'repo-a' '' 'repo-a' 'arg1'
# REPO_CLONE 'repo-b' '' 'repo-b' 'arg1'
# REPO_CLONE 'repo-c' '' 'repo-c' 'arg1'

SHELL ?= /usr/bin/bash

.DEFAULT_GOAL := all

REPO_BASE ?= /tmp/test

# ordered smallest to largest so quick ones go first!
REPOS ?= git_usbarmory_repo git_armoryctl_repo git_crucible_repo git_caam_keyblob_repo git_mxs_dcp_repo git_mxc_scc2_repo git_uboot_repo git_linux_repo 
.PHONY: $(REPOS)

all: $(REPOS)
.PHONY: all

# relies on the *shell* sourcing 'makefiles/Makefile.upstream' that contains variables pointing to each repository of the form:
# USBARMORY_REPO=https://github.com/usbarmory/usbarmory
# the file is formatted to be valid Makefile AND shell so can be used from both
define REPO_CLONE =
 $(1):
	target="$(1)"; \
	upper="$$$${target^^}"; \
	repo_url_var="$$$${upper#GIT_}"; \
	source makefiles/Makefile.upstream; \
	repo_url="$$$${!repo_url_var}"; \
	repo_name="$$$${repo_url##*/}"; \
	repo_dir="${REPO_BASE}/$$$${repo_name}"; \
	echo "target='$$$${target}' upper='$$$${upper}' repo_url_var='$$$${repo_url_var}' repo_url='$$$${repo_url}' repo_name='$$$${repo_name}' repo_dir='$$$${repo_dir}'"; \
	if ! test -d "$$$${repo_dir}"; then \
		if ! test -d "$$$${repo_dir%/*}"; then \
			mkdir --parents "$$$${repo_dir%/*}"; \
		fi; \
		git clone "$$$${repo_url}.git" "$$$${repo_dir}"; \
	fi;
endef

$(foreach repo,$(REPOS),$(eval $(call REPO_CLONE,$(repo),arg1)))

